CREATE TABLE classified (
 classified_id %%INCREMENT%%,
 posted_on     datetime not null, 
 posted_by     %%INCREMENT_TYPE%% not null,
 title         varchar(50) null,
 organization  varchar(75) null,
 deadline      date null,
 description   text null,
 location      varchar(200) null,
 required_skills text null,
 recommended_skills text null,
 application_info text null,
 contact       varchar(100) null,
 phone         varchar(50) null,
 fax           varchar(50) null,
 email         varchar(75) null,
 url           varchar(75) null,
 active        char(3) default 'yes',
 expires_on    datetime null,
 active_on     datetime null,
 primary key   ( classified_id )
)